@@ -8,8 +8,8 @@ if TYPE_CHECKING:
 
 
 class PMMatplotlibQt5Widget(QWidget):
-    def __init__(self):
-        super().__init__()
+    def __init__(self,parent=None):
+        super().__init__(parent)
         self.figure = plt.figure(facecolor='#FFD7C4')  # 可选参数,facecolor为背景颜色
         self.canvas = FigureCanvasQTAgg(self.figure)
         layout = QVBoxLayout()
@@ -19,22 +19,5 @@ class PMMatplotlibQt5Widget(QWidget):
     def add_subplot(self, param) -> 'Axes':
         return self.figure.add_subplot(param)
 
-
-# 运行程序
-if __name__ == '__main__':
-    app = QApplication(sys.argv)
-    pmqt5mplwgt = PMMatplotlibQt5Widget()
-    pmqt5mplwgt.show()
-
-
-    def draw():
-        ax = pmqt5mplwgt.add_subplot(121)
-        ax2 = pmqt5mplwgt.add_subplot(122)
-        ax.plot([1, 2, 3])
-        ax.set_xlabel('test_x_label')
-        ax2.set_xlabel('test_2')
-        ax2.plot([1,3,1,4,15])
-        pmqt5mplwgt.canvas.draw()
-
-    draw()
-    app.exec()
+    def draw(self)->None:
+        self.canvas.draw()
