@@ -60,13 +60,14 @@ class BaseParamWidget(QWidget):
     def get_value(self):
         pass
 
+    def set_params(self,*args,**kwargs):
+        pass
+
 
 class NumCtrl(BaseParamWidget):
     """NumCtrl: derived from tk.Entry
     用于输入数值。
     """
-
-    # (int, 'age', 'How old are you?', 88, 'years old', (0, 150)),
     def __init__(self, layout_dir: str, title: str, initial_value: int, unit: str, rang: tuple):
         super().__init__(layout_dir=layout_dir)
         self.on_check_callback = None
@@ -635,29 +636,46 @@ class ChoiceBoxCtrl(BaseParamWidget):
 
 views_dic = {str: TextCtrl, int: NumCtrl, float: NumCtrl, bool: Check, list: Choice}
 views_dic.update({'choose_box': ChoiceBoxCtrl, 'chos': Choices, 'color': ColorCtrl, 'number': NumCtrl
-                     , 'line_edit': TextCtrl, 'slide': FloatSlider, 'lab': Label,'bool':Check})
+                     , 'line_edit': TextCtrl, 'slide': FloatSlider, 'lab': Label, 'bool': Check})
 
 
 class SettingsPanel(QWidget):
     widgets_dic: Dict[str, BaseParamWidget] = {}
 
-    def __init__(self, views: List[Tuple[str]] = None, parent=None, layout_dir: str = 'v'):
+    def __init__(self, parent=None, views: List[Tuple[str]] = None, layout_dir: str = 'v'):
         super(SettingsPanel, self).__init__(parent)
-
-        self.widgets_dic: Dict[str, QWidget] = {}
+        self.layout_dir = layout_dir
         if layout_dir == 'v':
             self.setLayout(QVBoxLayout())
         else:
             self.setLayout(QHBoxLayout())
+
+        self.set_items(views)
+
+    def _set_items(self, views: List[Tuple[str]] = None):
+        if views is None:
+            return
+        self.widgets_dic: Dict[str, QWidget] = {}
         self.layout().setContentsMargins(0, 0, 0, 0)
         for v in views:
             name = v[1]
-            widget = views_dic[v[0]](layout_dir, *v[2:])
+            widget = views_dic[v[0]](self.layout_dir, *v[2:])
             if self.widgets_dic.get(name) is None:
                 self.widgets_dic[name] = widget
             self.layout().addWidget(widget)
         self.layout().addItem(QSpacerItem(0, 0, QSizePolicy.Minimum, QSizePolicy.Expanding))
 
+    def set_items(self, items: List[Tuple[str]] = None):
+        self.widgets_dic = {}
+        for i in range(self.layout().count()):
+            item = self.layout().itemAt(i).widget()
+            if item is not None:
+                item.deleteLater()
+        self._set_items(items)
+
+    def get_ctrl(self,ctrl_name:str):
+        return self.widgets_dic.get(ctrl_name)
+
     def get_value(self):
         result = {}
         for k in self.widgets_dic:
@@ -682,6 +700,7 @@ if __name__ == '__main__':
              ('color', 'color', 'Which color do u like?', (0, 200, 0))]
     sp = SettingsPanel(views=views, layout_dir='v')
     sp.widgets_dic['plane_type'].set_choices(['aaa', 'vvvvv', 'xxxxxx'])
+    sp.set_items(views[3:6])
     sp.show()
     sp2 = SettingsPanel(views=views, layout_dir='h')
     sp2.show()
