@@ -1,5 +1,5 @@
 import os
-from PyQt5.QtCore import Qt, QModelIndex, pyqtSignal
+from PyQt5.QtCore import Qt, QModelIndex, pyqtSignal, QLocale,QTranslator
 from PyQt5.QtGui import QCursor
 from PyQt5.QtWidgets import QTreeView, QFileSystemModel, QMenu, QApplication, QMessageBox, QInputDialog, \
     QLineEdit
@@ -45,6 +45,13 @@ class PMGFilesTreeview(QTreeView):
         界面初始化
         :return:
         '''
+        path = os.path.join(os.path.dirname(__file__), 'translations', 'qt_{0}.qm'.format(QLocale.system().name()))
+        app = QApplication.instance()
+        translator = QTranslator()
+        translator.load(path)
+        app.installTranslator(translator)
+        self.translator = translator
+
         self.setTabKeyNavigation(True)
         self.setDragEnabled(True)
         self.setDragDropOverwriteMode(True)
